==> haskell-crypton-x509-store-1.6.9-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypton-x509-store
version:              1.6.9
visibility:           public
id:                   crypton-x509-store-1.6.9-KEWQ3oc5BCnBNJByOFeRN0
key:                  crypton-x509-store-1.6.9-KEWQ3oc5BCnBNJByOFeRN0
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list

category:             Data
abi:                  77ac0507dbbcf25fe60a4ea7e77a2c9e
exposed:              True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory

import-dirs:          /usr/lib/ghc-9.0.2/site-local/crypton-x509-store-1.6.9
library-dirs:         /usr/lib/ghc-9.0.2/site-local/crypton-x509-store-1.6.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-store
hs-libraries:         HScrypton-x509-store-1.6.9-KEWQ3oc5BCnBNJByOFeRN0
depends:
    asn1-encoding-0.9.6-DwUky2iBreIC6bbIXJDOoo
    asn1-types-0.3.4-6wpoE5PoEIAJgIMZ40ZnuH base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1
    crypton-0.32-JkPj4NTo5F7CfmkMW2doQD
    crypton-x509-1.7.6-FKDle6vcmAi8HDLrboJuXG directory-1.3.6.2
    filepath-1.4.2.1 mtl-2.2.2 pem-0.2.4-4peApW3gfWj4GFBAgRMCEc

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-store/html/crypton-x509-store.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-x509-store-1.6.9-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypton-x509-store
version:              1.6.9
visibility:           public
id:                   crypton-x509-store-1.6.9-86iOfXe0P7uLpyFO8WgCHc
key:                  crypton-x509-store-1.6.9-86iOfXe0P7uLpyFO8WgCHc
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list

category:             Data
abi:                  8ccf547751f39fdaa07369094f314915
exposed:              True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory

import-dirs:          /usr/lib/ghc-9.0.2/site-local/crypton-x509-store-1.6.9
library-dirs:         /usr/lib/ghc-9.0.2/site-local/crypton-x509-store-1.6.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-store
hs-libraries:         HScrypton-x509-store-1.6.9-86iOfXe0P7uLpyFO8WgCHc
depends:
    asn1-encoding-0.9.6-AAtkw5TY9F8VurSKdIoeL
    asn1-types-0.3.4-aUYrrqmCzsAxNNdefID82 base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1
    crypton-0.32-I25Or2u1KXpL7IAB7bK2rz
    crypton-x509-1.7.6-C7Qr4M5ilfnDiz0UC7ZYag directory-1.3.6.2
    filepath-1.4.2.1 mtl-2.2.2 pem-0.2.4-1mbRPloOMhKLwKtT5g0UYJ

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-store/html/crypton-x509-store.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
